==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/core/reflect/FormatTimeUtil.java <==
package cn.gtmap.realestate.supervise.core.reflect;

import com.gtis.common.util.UUIDGenerator;
import org.apache.commons.lang3.StringUtils;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:Administrator@gtmap.cn">Administrator</a>
 * @version 1.0, 2017/4/6
 * @description
 */
public class FormatTimeUtil {
    public static void changeObjectFormate(Object o, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName, String recType) throws InvocationTargetException, IllegalAccessException, ParseException {
        getKey(o, areaCode, exchangeQxdm, bdcdyh, ywh, fileName, recType);
    }

    public static void getKey(Object o, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName,String recType) throws InvocationTargetException, IllegalAccessException, ParseException {
        List<String> params = new ArrayList<String>();
        Class<?> c = o.getClass();
        Field[] field = c.getDeclaredFields();
        for (Field f : field) {
            id id = f.getAnnotation(id.class);
            ywh ywhTemp = f.getAnnotation(ywh.class);
            qxdm qxdm = f.getAnnotation(qxdm.class);
            bdcdyh bdcdyh1 = f.getAnnotation(bdcdyh.class);
            ssywh ssywhTemp = f.getAnnotation(ssywh.class);
            zxywh zxywhTemp = f.getAnnotation(zxywh.class);
            zxdyywh zxdyywhTemp = f.getAnnotation(zxdyywh.class);
            zxjzqywh zxjzqywhTemp = f.getAnnotation(zxjzqywh.class);
            zxyyywh zxyyywhTemp = f.getAnnotation(zxyyywh.class);
            jfywh jfywhTemp = f.getAnnotation(jfywh.class);
            zxygywh zxygywhTemp = f.getAnnotation(zxygywh.class);
            bwmc bwmc = f.getAnnotation(bwmc.class);
            slbh slbh = f.getAnnotation(slbh.class);
            sqlx sqlx = f.getAnnotation(sqlx.class);
            if (id != null) {
                params.add(f.getName());
            }
            if (null != ywhTemp) {
                params.add(f.getName());
            }
            if (null != qxdm) {
                params.add(f.getName());
            }
            if (null != bdcdyh1) {
                params.add(f.getName());
            }
            if (null != ssywhTemp) {
                params.add(f.getName());
            }
            if (null != zxywhTemp) {
                params.add(f.getName());
            }
            if (null != zxdyywhTemp) {
                params.add(f.getName());
            }
            if (null != zxyyywhTemp) {
                params.add(f.getName());
            }
            if (null != zxjzqywhTemp) {
                params.add(f.getName());
            }
            if (null != jfywhTemp) {
                params.add(f.getName());
            }
            if (null != zxygywhTemp) {
                params.add(f.getName());
            }
            if (null != bwmc) {
                params.add(f.getName());
            }
            if (null != slbh) {
                params.add(f.getName());
            }
            if (null != sqlx) {
                params.add(f.getName());
            }
        }
        dealMethods(o, params, areaCode, exchangeQxdm, bdcdyh, ywh, fileName,recType);
    }


    public static void dealMethods(Object source, List<String> params, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName,String recType) throws InvocationTargetException, IllegalAccessException {

        Method[] sourceMethods = source.getClass().getMethods();
        Class clazz = source.getClass();   //获取字节码对象
        for (int i = 0; i < sourceMethods.length; i++) {
            String nameStr = sourceMethods[i].getName();
            if (nameStr.startsWith("get")) {
                String proName = nameStr.substring(3).toLowerCase();
                Field field = null; //暴力反射获取字段
                Method me = null;
                try {
                    if (params.contains(proName) && StringUtils.equals("id", proName)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        String uuid = UUIDGenerator.generate18();
                        field.set(source, uuid);   //设置值
                    }
                    if (params.contains(proName) && StringUtils.equals("ywh", proName) && StringUtils.isNotBlank(areaCode)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        } else {
                            field.set(source, ywh);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("qxdm", proName) && StringUtils.isNotBlank(exchangeQxdm)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            field.set(source, exchangeQxdm);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("bdcdyh", proName)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isBlank(proValue)) {
                            field.set(source, bdcdyh);   //设置值
                        }
                    }
                    if (params.contains(proName) && StringUtils.equals("ssywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxywh", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxyyywh", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxdyywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxjzqywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("slbh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String slbh = areaCode + "_" + proValue;
                            field.set(source, slbh);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxygywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("jfywh", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }
                    if (params.contains(proName) && StringUtils.equals("bwmc", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        field.set(source, fileName);   //设置值
                    }

                    if (params.contains(proName) && StringUtils.equals("sqlx", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        field.set(source, recType);   //设置值
                    }
                } catch (NoSuchMethodException e) {
                    e.printStackTrace();
                } catch (NoSuchFieldException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * 首字母大写公共方法
     *
     * @param str
     * @return
     */
    public static String upperCase(String str) {
        return str.substring(0, 1).toUpperCase() + str.substring(1);
    }

}

==> realestate-supervise-common-1.1.0-20251204.031512-72-sources.jar: cn/gtmap/realestate/supervise/core/reflect/FormatTimeUtil.java <==
package cn.gtmap.realestate.supervise.core.reflect;

import com.gtis.common.util.UUIDGenerator;
import org.apache.commons.lang3.StringUtils;

import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;

/**
 * @author <a href="mailto:Administrator@gtmap.cn">Administrator</a>
 * @version 1.0, 2017/4/6
 * @description
 */
public class FormatTimeUtil {
    public static void changeObjectFormate(Object o, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName, String recType) throws InvocationTargetException, IllegalAccessException, ParseException {
        getKey(o, areaCode, exchangeQxdm, bdcdyh, ywh, fileName, recType, "");
    }

    public static void DijiChangeObjectFormate(Object o, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName, String recType, String jgbsm) throws InvocationTargetException, IllegalAccessException, ParseException {
        getKey(o, areaCode, exchangeQxdm, bdcdyh, ywh, fileName, recType, jgbsm);
    }

    public static void getKey(Object o, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName,String recType, String jgbsm) throws InvocationTargetException, IllegalAccessException, ParseException {
        List<String> params = new ArrayList<String>();
        Class<?> c = o.getClass();
        Field[] field = c.getDeclaredFields();
        for (Field f : field) {
            id id = f.getAnnotation(id.class);
            ywh ywhTemp = f.getAnnotation(ywh.class);
            qxdm qxdm = f.getAnnotation(qxdm.class);
            bdcdyh bdcdyh1 = f.getAnnotation(bdcdyh.class);
            ssywh ssywhTemp = f.getAnnotation(ssywh.class);
            zxywh zxywhTemp = f.getAnnotation(zxywh.class);
            zxdyywh zxdyywhTemp = f.getAnnotation(zxdyywh.class);
            zxjzqywh zxjzqywhTemp = f.getAnnotation(zxjzqywh.class);
            zxyyywh zxyyywhTemp = f.getAnnotation(zxyyywh.class);
            jfywh jfywhTemp = f.getAnnotation(jfywh.class);
            zxygywh zxygywhTemp = f.getAnnotation(zxygywh.class);
            bwmc bwmc = f.getAnnotation(bwmc.class);
            slbh slbh = f.getAnnotation(slbh.class);
            sqlx sqlx = f.getAnnotation(sqlx.class);
            if (id != null) {
                params.add(f.getName());
            }
            if (null != ywhTemp) {
                params.add(f.getName());
            }
            if (null != qxdm) {
                params.add(f.getName());
            }
            if (null != bdcdyh1) {
                params.add(f.getName());
            }
            if (null != ssywhTemp) {
                params.add(f.getName());
            }
            if (null != zxywhTemp) {
                params.add(f.getName());
            }
            if (null != zxdyywhTemp) {
                params.add(f.getName());
            }
            if (null != zxyyywhTemp) {
                params.add(f.getName());
            }
            if (null != zxjzqywhTemp) {
                params.add(f.getName());
            }
            if (null != jfywhTemp) {
                params.add(f.getName());
            }
            if (null != zxygywhTemp) {
                params.add(f.getName());
            }
            if (null != bwmc) {
                params.add(f.getName());
            }
            if (null != slbh) {
                params.add(f.getName());
            }
            if (null != sqlx) {
                params.add(f.getName());
            }
        }
        dealMethods(o, params, areaCode, exchangeQxdm, bdcdyh, ywh, fileName,recType, jgbsm);
    }


    public static void dealMethods(Object source, List<String> params, String areaCode, String exchangeQxdm, String bdcdyh, String ywh, String fileName,String recType, String jgbsm) throws InvocationTargetException, IllegalAccessException {

        Method[] sourceMethods = source.getClass().getMethods();
        Class clazz = source.getClass();   //获取字节码对象
        for (int i = 0; i < sourceMethods.length; i++) {
            String nameStr = sourceMethods[i].getName();
            if (nameStr.startsWith("get")) {
                String proName = nameStr.substring(3).toLowerCase();
                Field field = null; //暴力反射获取字段
                Method me = null;
                try {
                    if (params.contains(proName) && StringUtils.equals("id", proName)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        String uuid = UUIDGenerator.generate18();
                        field.set(source, uuid);   //设置值
                    }
                    if (params.contains(proName) && StringUtils.equals("ywh", proName) && StringUtils.isNotBlank(areaCode)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        } else {
                            field.set(source, ywh);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("qxdm", proName) && StringUtils.isNotBlank(exchangeQxdm)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            field.set(source, exchangeQxdm);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("bdcdyh", proName)) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isBlank(proValue)) {
                            field.set(source, bdcdyh);   //设置值
                        }
                    }
                    if (params.contains(proName) && StringUtils.equals("ssywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxywh", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxyyywh", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxdyywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxjzqywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("slbh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String slbh = areaCode + "_" + proValue;
                            field.set(source, slbh);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("zxygywh", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }

                    if (params.contains(proName) && StringUtils.equals("jfywh", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        me = clazz.getDeclaredMethod("get" + upperCase(proName));
                        String proValue = (String) me.invoke(source);
                        if (StringUtils.isNotBlank(proValue)) {
                            String ywhStr = areaCode + "_" + proValue;
                            field.set(source, ywhStr);   //设置值
                        }
                    }
                    if (params.contains(proName) && StringUtils.equals("bwmc", proName) && (null != areaCode && !areaCode.isEmpty())) {

                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        field.set(source, fileName);   //设置值
                    }

                    if (params.contains(proName) && StringUtils.equals("sqlx", proName) && (null != areaCode && !areaCode.isEmpty())) {
                        field = clazz.getDeclaredField(proName);
                        field.setAccessible(true); //设置访问权限
                        field.set(source, recType);   //设置值
                    }
                } catch (NoSuchMethodException e) {
                    e.printStackTrace();
                } catch (NoSuchFieldException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * 首字母大写公共方法
     *
     * @param str
     * @return
     */
    public static String upperCase(String str) {
        return str.substring(0, 1).toUpperCase() + str.substring(1);
    }

}
